@@ -32,7 +32,6 @@
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QFile>
-#include <QTextCodec>
 #include <QTextStream>
 #include <kio/netaccess.h>
 
@@ -356,5 +355,3 @@ void KgpgTextEdit::slotHighlightText(const QString &, const int matchingindex, c
 {
 	highlightWord(matchedlength, matchingindex);
 }
-
-#include "kgpgtextedit.moc"
