@@ -26,14 +26,9 @@
 #include "transactions/kgpgkeyserversearchtransaction.h"
 #include "transactions/kgpgsendkeys.h"
 
-#include <KConfig>
-#include <KDateTime>
-#include <KDebug>
 #include <KLocale>
 #include <KMessageBox>
 #include <QCursor>
-#include <QLabel>
-#include <QTextCodec>
 
 KeyServer::KeyServer(QWidget *parent, KGpgItemModel *model, const bool autoclose)
 	: KDialog(parent),
@@ -44,7 +39,7 @@ KeyServer::KeyServer(QWidget *parent, KGpgItemModel *model, const bool autoclose
 	m_resultmodel(Q_NULLPTR),
 	m_itemmodel(new KeyListProxyModel(this, KeyListProxyModel::SingleColumnIdFirst))
 {
-	setCaption(i18n("Key Server"));
+	setWindowTitle(i18n("Key Server"));
 	setButtons(Close);
 	setModal(false);
 
@@ -205,7 +200,7 @@ void KeyServer::slotSearch()
 	m_filtermodel.setFilterRegExp(QRegExp());
 
 	m_dialogserver = new KDialog(this );
-	m_dialogserver->setCaption( i18n("Import Key From Keyserver") );
+	m_dialogserver->setWindowTitle(i18n("Import Key From Keyserver"));
 	m_dialogserver->setButtons( KDialog::Ok | KDialog::Close );
 	m_dialogserver->setDefaultButton( KDialog::Ok);
 	m_dialogserver->setModal( true );
@@ -370,5 +365,3 @@ void KeyServer::slotSetFilterString(const QString &expression)
 {
 	m_filtermodel.setFilterRegExp(QRegExp(expression, Qt::CaseInsensitive, QRegExp::RegExp2));
 }
-
-#include "keyservers.moc"
